pub struct ThermalSystem {
pub nodes: HashMap<String, ThermalNetNode>,
pub edges: Vec<ThermalEdge>,
pub time: f64,
}Expand description
A lumped thermal network of nodes connected by conductance edges.
Fields
nodes: HashMap<String, ThermalNetNode>Nodes indexed by their id.
edges: Vec<ThermalEdge>Directed conductance edges (bidirectional heat flow).
time: f64Simulation time (s). Updated by transient solvers.
Implementations
Sourceimpl ThermalSystem
impl ThermalSystem
Sourcepub fn add_node(&mut self, node: ThermalNetNode) -> bool
pub fn add_node(&mut self, node: ThermalNetNode) -> bool
Add a node. Returns false if a node with the same id already exists.
Sourcepub fn add_edge(&mut self, edge: ThermalEdge)
pub fn add_edge(&mut self, edge: ThermalEdge)
Add a conductance edge.
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Number of nodes.